@@ -1,4 +1,4 @@
-# Copyright 2018 Globo.com
+# Copyright 2019 Globo.com
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -174,6 +174,24 @@ def audit_export_get(ctx, export_id):
     print_response(conn.audit_export_get(export_id))
 
 
+# id_custeio=1&mensagem=Custeio Inserido Com Sucesso&abertura=2019-07-16-00:00:00&fechamento=2019-07-16-23:59:59&json_custeio={teste:teste}
+@cli.command(name='audit-custeio-create')
+@click.option('--id_custeio', metavar='<id_custeio>', type=click.STRING,
+              required=True)
+@click.option('--mensagem', metavar='<mensagem>', type=click.STRING,
+              required=True)
+@click.option('--abertura', metavar='<abertura>', type=click.STRING,
+              required=True)
+@click.option('--fechamento', metavar='<fechamento>', type=click.STRING,
+              required=True)
+@click.option('--json_custeio', metavar='<json_custeio>',
+              type=click.STRING, required=True)
+@click.pass_context
+def audit_custeio_create(ctx, id_custeio, mensagem, abertura, fechamento, json_custeio):
+    conn = ctx.obj['CONN']
+    print_response(conn.audit_custeio_create(id_custeio, mensagem, abertura, fechamento, json_custeio))
+
+
 # apphost ----------------------------------------------------------------
 @cli.command(name='apphost-list')
 @click.pass_context
@@ -234,6 +252,13 @@ def export_list(ctx, host):
     print_response(conn.export_list(host))
 
 
+@cli.command(name='export-list-deleted')
+@click.pass_context
+def delete_export_list(ctx):
+    conn = ctx.obj['CONN']
+    print_response(conn.deleted_export_list())
+
+
 @cli.command(name='project-quota-get')
 @click.pass_context
 def export_get(ctx):
@@ -264,6 +289,21 @@ def export_create(ctx, quota, categoria, resource_id, time_id):
     print_response(conn.export_create(quota, categoria, resource_id, time_id))
 
 
+@cli.command(name='export-multiple-create')
+@click.option('--quota', metavar='<size in KB>', type=click.INT, required=True)
+@click.option('--categoria', metavar='<categoria>', type=click.INT,
+              required=True)
+@click.option('--resource_id', metavar='<resource_id>', type=click.STRING,
+              required=False)
+@click.option('--time-id', metavar='<time_id>', type=click.STRING,
+              required=False)
+@click.option('--amount', metavar='<amount>', type=click.INT, required=True)
+@click.pass_context
+def export_multiple_create(ctx, quota, categoria, resource_id, time_id, amount):
+    conn = ctx.obj['CONN']
+    print_response(conn.export_multiple_create(quota, categoria, resource_id, time_id, amount))
+
+
 @cli.command(name='export-delete')
 @click.option('export_id', '--id', metavar='<export_id or export_path>',
               type=click.INT, required=True)
@@ -589,12 +629,13 @@ def snapshot_restore(ctx, export_id, snapshot_id):
     conn = ctx.obj['CONN']
     print_response(conn.snapshot_restore(export_id, snapshot_id))
 
+
 # REPORT TO GLOBOMAP --------------------------------------------------------------
 @cli.command(name='report-get')
 @click.pass_context
 def report_get(ctx):
     conn = ctx.obj['CONN']
-    print json.dumps(conn.report_get())
+    print(json.dumps(conn.report_get()))
 
 
 # PRINTS -----------------------------------------------------------------
