@@ -1,4 +1,4 @@
-# Copyright 2018 Globo.com
+# Copyright 2019 Globo.com
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -159,6 +159,12 @@ class Client(object):
 
         return self._get_request(url_path)
 
+    def audit_custeio_create(self, id_custeio, mensagem, abertura, fechamento, json_custeio):
+        url_path = '/custeio_audit'
+        data = {'id_custeio': id_custeio, 'mensagem': mensagem, 'abertura': abertura, 'fechamento': fechamento, 'json_custeio': json_custeio}
+
+        return self._post_request(url_path, data)
+
     # APPHOST  ------------------------------------------------------------
     def apphost_list(self):
         url_path = '/apphosts'
@@ -195,17 +201,41 @@ class Client(object):
         url_path = '/exports/{}'.format(export_id_or_path)
         return self._get_request(url_path)
 
-    def export_list(self, host=None):
+    def export_list(self, host=None, extra=None):
+        url_path = '/exports'
+        params = {}
+        query_str = ''
+
         if host:
-            url_path = '/exports?host={}'.format(host)
-        else:
-            url_path = '/exports'
+            params['host'] = host
+
+        if extra:
+            params['extra'] = extra
+
+        for i, key in enumerate(params.keys()):
+            if i > 0:
+                query_str += '&'
+            query_str += '{}={}'.format(key, params[key])
+
+        if len(query_str) > 0:
+            url_path = '{}?{}'.format(url_path, query_str)
+
+        return self._get_request(url_path)
+
+    def deleted_export_list(self):
+        url_path = '/exports/deleted'
         return self._get_request(url_path)
 
     def export_create(self, quota, categoria, resource_id=None, time_id=None, audit=False):
         url_path = '/exports'
         data = {'quota': quota, 'categoria': categoria, 'resource_id': resource_id, 'time_id': time_id}
-        
+
+        return self._post_request(url_path, data, audit=audit)
+
+    def export_multiple_create(self, quota, categoria, resource_id=None, time_id=None, amount=None, audit=False):
+        url_path = '/exports/multiple'
+        data = {'quota': quota, 'categoria': categoria, 'resource_id': resource_id, 'time_id': time_id, 'amount': amount}
+
         return self._post_request(url_path, data, audit=audit)
 
     def export_delete(self, export_id_or_path, audit=False):
@@ -225,15 +255,23 @@ class Client(object):
     def export_group(self, exports_id, resource_id, audit=False):
         url_path = '/exports/resource'
         data = {'exports': exports_id, 'resource_id': resource_id}
-        
+
         return self._post_request(url_path, data, audit=audit)
 
     def exports_time(self, exports_id, time_id, audit=False):
         url_path = '/exports/time'
         data = {'exports': exports_id, 'time_id': time_id}
-        
+
         return self._post_request(url_path, data, audit=audit)
 
+    def export_by_id_or_path(self, export_id_or_path):
+        url_path = '/notenant/exports/{}'.format(export_id_or_path)
+        return self._get_request(url_path)
+
+    def export_all_list(self):
+        url_path = '/notenant/exports'
+        return self._get_request(url_path)
+
     # FILER  ------------------------------------------------------------------
     def filer_list(self):
         url_path = '/filers'
@@ -241,7 +279,7 @@ class Client(object):
         return self._get_request(url_path)
 
     def filer_create(self, vfiler, export_filer, connection_filer, username,
-                     password):
+                     password, vserver):
         url_path = '/filers'
         data = {
             'vfiler': vfiler,
@@ -249,6 +287,7 @@ class Client(object):
             'connection_filer': connection_filer,
             'username': username,
             'password': password,
+            'vserver': vserver,
         }
 
         return self._post_request(url_path, data)
@@ -264,7 +303,7 @@ class Client(object):
         return self._delete_request(url_path)
 
     def filer_update(self, filer_id, vfiler, export_filer, connection_filer,
-                     username, password):
+                     username, password, vserver):
         url_path = '/filers/{}'.format(filer_id)
         data = {
             'vfiler': vfiler,
@@ -272,6 +311,7 @@ class Client(object):
             'connection_filer': connection_filer,
             'username': username,
             'password': password,
+            'vserver': vserver,
         }
 
         return self._put_request(url_path, data)
@@ -417,7 +457,6 @@ class Client(object):
 
     # REQUESTS
     def _request(self, method, url_path, data=None, headers=None, audit=False):
-
         if not self.token:
             project_url, self.token = self.get_auth()
 
@@ -428,29 +467,35 @@ class Client(object):
         headers['X-Storage-Token'] = self.token
         url = self.url + url_path
 
+        if '/notenant' in url_path:
+            parsed = urlparse(self.url)
+            url_path = ''.join(url_path.split('/notenant')[1:])
+
+            url = '{}://{}{}'.format(parsed.scheme, parsed.hostname, url_path)
+
         if url_path == '/report':
             parsed = urlparse(self.url)
-            
+
             url = '{}://{}{}'.format(parsed.scheme, parsed.hostname, url_path)
 
         r = requests.request(method, url, data=data, headers=headers,
-                             verify=not self.insecure)
-        
+                             verify=not self.insecure, timeout=1800)
+
         if audit:
             return r
-        
+
         try:
             response = r.json()
         except ValueError:
             response = ''
-        
+
         return r.status_code, response
 
     def _get_request(self, url_path, headers=None):
         return self._request('get', url_path, headers=headers)
 
     def _post_request(self, url_path, data=None, headers=None, audit=False):
-        
+
         return self._request('post', url_path, data=data, headers=headers, audit=audit)
 
     def _put_request(self, url_path, data, headers=None, audit=False):
